import numpy as np

def get_mean(number_array: np.ndarray) -> float:
    return np.mean(number_array)

def get_max(number_array: np.ndarray) -> float:
    return np.max(number_array)

def get_min(number_array: np.ndarray) -> float:
    return np.min(number_array)

def get_sum(number_array: np.ndarray) -> float:
    return np.sum(number_array)

